# S.O.L.I.D-Backend

## What is S.O.L.I.D?


## Documentation

Coming soon...

## Coverage

Coming soon...

## Try it out and local development

For a How-To guide see the README in the sample_project directory.

